"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BookRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class BookRecord {
    constructor(obj) {
        if (!obj.title || obj.title.length > 200) {
            throw new errors_1.ValidationError('Title of the book field cannot be empty and longer than 200');
        }
        if (!obj.author || obj.author.length > 100) {
            throw new errors_1.ValidationError('Author field cannot be empty and longer than 100');
        }
        if (!obj.description || obj.description.length > 1000) {
            throw new errors_1.ValidationError('Description field cannot be empty and longer than 1000');
        }
        if (typeof obj.review !== "number") {
            throw new errors_1.ValidationError('Review field has to be a number');
        }
        this.id = obj.id;
        this.title = obj.title;
        this.author = obj.author;
        this.description = obj.description;
        this.review = obj.review;
        this.count = obj.count;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `books` WHERE id = :id", {
                id,
            });
            return results.length === 0 ? null : new BookRecord(results[0]);
        });
    }
    static findAll(title) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `books` WHERE `title` LIKE :search", {
                search: `%${title}%`
            });
            return results.map(result => new BookRecord(result));
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new errors_1.ValidationError("Cannot insert something that already exists");
            }
            yield db_1.pool.execute("INSERT INTO `books` (`id`, `title`, `author`, `description`, `review`, `count`) VALUES (:id, :title, :author, :description, :review, :count)", this);
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `books` WHERE `id` =:id", {
                id: this.id
            });
        });
    }
}
exports.BookRecord = BookRecord;
//# sourceMappingURL=book.record.js.map