"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
class UserRecord {
    constructor(obj) {
        if (!obj.firstname || obj.firstname.length > 100) {
            throw new errors_1.ValidationError('Firstname field cannot be empty and longer than 100');
        }
        if (!obj.lastname || obj.lastname.length > 100) {
            throw new errors_1.ValidationError('Lastname field cannot be empty and longer than 100');
        }
        if (!obj.address || obj.address.length > 1000) {
            throw new errors_1.ValidationError('Address field cannot be empty and longer than 1000');
        }
        if (obj.password.length < 6) {
            throw new errors_1.ValidationError('Password field cannot be shorter than 6');
        }
        this.id = obj.id;
        this.firstname = obj.firstname;
        this.lastname = obj.lastname;
        this.password = obj.password;
        this.address = obj.address;
        this.email = obj.email;
        this.username = obj.username;
        this.bookId = obj.username;
        this.currentTokenId = obj.currentTokenId;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE id = :id", {
                id,
            });
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static getOneWithEmail(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE email = :email", {
                email,
            });
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static getOneWithToken(currentTokenId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE currentTokenId = :currentTokenId", {
                currentTokenId,
            });
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static findAll(lastname) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE `lastname` LIKE :search", {
                search: `%${lastname}%`
            });
            return results.map(result => new UserRecord(result));
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new errors_1.ValidationError("Cannot insert somebody that already exists");
            }
            yield db_1.pool.execute("INSERT INTO `users` (`id`, `firstname`, `lastname`, `address`, `password`, `email`, `username`) VALUES (:id, :firstname, :lastname, :address, :password, :email, :username)", this);
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `users` WHERE `id` =:id", {
                id: this.id
            });
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `users` SET `firstname` = :firstname, `lastname` = :lastname, `address` = :address, `password` = :password, `email` = :email, `username` = :username, `currentTokenId` = :currentTokenId WHERE `id` = :id", {
                id: this.id,
                firstname: this.firstname,
                lastname: this.lastname,
                address: this.address,
                password: this.password,
                email: this.email,
                username: this.username,
                // bookId: this.bookId,
                currentTokenId: this.currentTokenId,
            });
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map