"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userRouter = void 0;
const express_1 = require("express");
const user_record_1 = require("../records/user.record");
const errors_1 = require("../utils/errors");
const has_pwd_1 = require("../utils/has-pwd");
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
require("dotenv/config");
exports.userRouter = (0, express_1.Router)()
    .get('/search/:lastname?', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const users = yield user_record_1.UserRecord.findAll((_a = req.params.lastname) !== null && _a !== void 0 ? _a : '');
    res.json(users);
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getOne(req.params.id);
    res.json(user);
}))
    .post('/register', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord(Object.assign(Object.assign({}, req.body), { password: yield (0, has_pwd_1.hashPwd)(req.body.password) }));
    yield user.insert();
    const { id, email } = user;
    res.json({ id, email });
}))
    .patch('/login', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getOneWithEmail(req.body.email);
    if (!user) {
        throw new errors_1.ValidationError("There is no such user.");
    }
    if ((0, has_pwd_1.hashPwd)(req.body.password) !== user.password) {
        throw new errors_1.ValidationError("Wrong password!");
    }
    const payload = {
        "email": user.email,
        "id": user.id,
    };
    const accessToken = jsonwebtoken_1.default.sign(payload, process.env.ACCESS_TOKEN_SECRET, { expiresIn: '5m' });
    const refreshToken = jsonwebtoken_1.default.sign(payload, process.env.REFRESH_TOKEN_SECRET, { expiresIn: '1d' });
    user.currentTokenId = refreshToken === null ? null : refreshToken;
    yield user.update();
    res.cookie('refreshToken', refreshToken, {
        // httpOnly: true,
        maxAge: 24 * 60 * 60 * 1000,
    });
    res.json({ accessToken, refreshToken });
}))
    .delete('/logout', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { refreshToken } = req.body;
    if (!refreshToken) {
        throw new errors_1.ValidationError("There is no such token.");
    }
    ;
    const user = yield user_record_1.UserRecord.getOneWithToken(refreshToken);
    if (!user) {
        throw new errors_1.ValidationError("There is no such user.");
    }
    user.currentTokenId = null;
    yield user.update();
    res.clearCookie('refreshToken');
    return res.sendStatus(200);
}))
    .delete('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getOne(req.params.id);
    if (!user) {
        throw new errors_1.ValidationError('There is no such user.');
    }
    yield user.delete();
    res.end();
}));
// .patch('/book/:userId', async (req, res) => {
//     const user = await UserRecord.getOne(req.params.userId);
//
//     if (user === null) {
//         throw new ValidationError('There is no such user.');
//     }
//
//     const book = (req.body as SetBookForUserReq).bookId === '' ? null : await BookRecord.getOne(req.body.bookId);
//
//     if (book) {
//         if (book.count <= await book.countGivenBooks()) {
//             throw new ValidationError('The book is already taken.');
//         }
//     }
//
//     user.bookId = book === null ? null : book.id
//
//     await user.update();
//
//     res.json(user);
// });
//# sourceMappingURL=user.router.js.map