"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../utils/db");
const book_record_1 = require("../records/book.record");
const defaultObj = {
    title: "Test title",
    author: "Test author",
    description: "Test description.",
    review: 0,
    count: 1,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('BookRecord.getOne returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const book = yield book_record_1.BookRecord.getOne('a');
    console.log(book);
    expect(book).toBeDefined();
    expect(book.id).toBe('a');
    expect(book.title).toBe('Potop');
}));
test('BookRecord.getOne returns null from database for no existing entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const book = yield book_record_1.BookRecord.getOne('---');
    expect(book).toBeNull();
}));
test('BookRecord.findAll returns an array of found entries from database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const books = yield book_record_1.BookRecord.findAll('');
    expect(books).not.toEqual([]);
    expect(books[0].id).toBeDefined();
}));
test('BookRecord.findAll returns an array of found entries from database when searching for t.', () => __awaiter(void 0, void 0, void 0, function* () {
    const books = yield book_record_1.BookRecord.findAll('t');
    expect(books).not.toEqual([]);
    expect(books[0].id).toBeDefined();
}));
test('BookRecord.findAll returns an empty array of found entries from database when searching for something which does not exist.', () => __awaiter(void 0, void 0, void 0, function* () {
    const books = yield book_record_1.BookRecord.findAll('-------------------------------');
    expect(books).toEqual([]);
}));
test('BookRecord.insert returns UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const book = new book_record_1.BookRecord(defaultObj);
    yield book.insert();
    expect(book.id).toBeDefined();
    expect(typeof book.id).toBe('string');
}));
test('BookRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const book = new book_record_1.BookRecord(defaultObj);
    yield book.insert();
    const foundBook = yield book_record_1.BookRecord.getOne(book.id);
    expect(foundBook).toBeDefined();
    expect(foundBook).not.toBeNull();
    expect(foundBook.id).toBe(book.id);
}));
test('BookRecord.delete deletes a record from database when we delete a record which exists', () => __awaiter(void 0, void 0, void 0, function* () {
    const book = yield book_record_1.BookRecord.getOne("w");
    yield book.delete();
    const deletedBook = yield book_record_1.BookRecord.getOne("w");
    expect(deletedBook).toEqual(null);
}));
//# sourceMappingURL=book.test.js.map