"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../utils/db");
const user_record_1 = require("../records/user.record");
const book_record_1 = require("../records/book.record");
const defaultObj = {
    firstname: "Test title",
    lastname: "Test author",
    address: "Test description.",
    password: "123456",
    email: 'a@w.p',
    username: 'byku',
    bookId: '',
    currentTokenId: '',
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('UserRecord.getOne returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getOne('1');
    console.log(user);
    expect(user).toBeDefined();
    expect(user.id).toBe('1');
    expect(user.firstname).toBe('Kamil');
}));
test('UserRecord.getOne returns null from database for no existing entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getOne('---');
    expect(user).toBeNull();
}));
test('UserRecord.findAll returns an array of found entries from database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const users = yield user_record_1.UserRecord.findAll('');
    expect(users).not.toEqual([]);
    expect(users[0].id).toBeDefined();
}));
test('UserRecord.findAll returns an array of found entries from database when searching for S.', () => __awaiter(void 0, void 0, void 0, function* () {
    const users = yield user_record_1.UserRecord.findAll('S');
    expect(users).not.toEqual([]);
    expect(users[0].id).toBeDefined();
}));
test('UserRecord.findAll returns an empty array of found entries from database when searching for something which does not exist.', () => __awaiter(void 0, void 0, void 0, function* () {
    const users = yield user_record_1.UserRecord.findAll('-------------------------------');
    expect(users).toEqual([]);
}));
test('UserRecord.insert returns UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord(defaultObj);
    yield user.insert();
    expect(user.id).toBeDefined();
    expect(typeof user.id).toBe('string');
}));
test('UserRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = new user_record_1.UserRecord(defaultObj);
    yield user.insert();
    const foundUser = yield user_record_1.UserRecord.getOne(user.id);
    expect(foundUser).toBeDefined();
    expect(foundUser).not.toBeNull();
    expect(foundUser.id).toBe(user.id);
}));
test('UserRecord.delete deletes a record from database when we delete a record which exists', () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield user_record_1.UserRecord.getOne("654321");
    yield user.delete();
    const deletedUser = yield book_record_1.BookRecord.getOne("654321");
    expect(deletedUser).toEqual(null);
}));
//# sourceMappingURL=user.test.js.map